@@ -1,20 +1,29 @@
 package Sah::Schema::hos;
 
-our $DATE = '2016-12-09'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Collection'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [hash => {
-    summary => 'Hash of strings',
+    summary => 'Hash of (defined) strings',
     description => <<'_',
 
-Note that for flexibility, the strings are allowed to be undefs.
-
 _
-    of => ['str', {}, {}],
+    of => ['str', {req=>1}, {}],
+    examples => [
+        {data=>'a', valid=>0},
+        {data=>[], valid=>0},
+        {data=>{}, valid=>1},
+        {data=>{k=>'a'}, valid=>1},
+        {data=>{k=>undef}, valid=>0},
+        {data=>{k=>'a', k2=>[]}, valid=>0},
+        {data=>{k=>'a', k2=>{}}, valid=>0},
+    ],
 }, {}];
 
 1;
-# ABSTRACT: Hash of strings
+# ABSTRACT: Hash of (defined) strings
 
 __END__
 
@@ -24,16 +33,14 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::hos - Hash of strings
+Sah::Schema::hos - Hash of (defined) strings
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::hos (from Perl distribution Sah-Schemas-Collection), released on 2016-12-09.
+This document describes version 0.002 of Sah::Schema::hos (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
-Note that for flexibility, the strings are allowed to be undefs.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Collection>.
@@ -50,13 +57,18 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah::Schema::homs> (hash of maybe-strings) where the values of the hash
+key-pairs are allowed to be undefs.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
